Crate ts_parser_pod

Crate ts_parser_pod 

This crate provides pod language support for the tree-sitter parsing library.

Typically, you will use the [language][language func] function to add this language to a tree-sitter Parser, and then use the parser to parse some code:

let code = "";
let mut parser = tree_sitter::Parser::new();
let language = ts_parser_pod::LANGUAGE;
parser.set_language(&language.into()).expect("Error loading pod grammar");
let tree = parser.parse(code, None).unwrap();

Constants

HIGHLIGHTS_QUERY
LANGUAGE
The tree-sitter LanguageFn for this grammar.
NODE_TYPES
The content of the node-types.json file for this grammar.